Struct amazon_sp_services::models::get_appointment_slots_response::GetAppointmentSlotsResponse
source · [−]pub struct GetAppointmentSlotsResponse {
pub payload: Option<Box<AppointmentSlotReport>>,
pub errors: Option<Vec<Error>>,
}Expand description
GetAppointmentSlotsResponse : The response of fetching appointment slots based on service context.
Fields
payload: Option<Box<AppointmentSlotReport>>errors: Option<Vec<Error>>A list of error responses returned when a request is unsuccessful.
Implementations
sourceimpl GetAppointmentSlotsResponse
impl GetAppointmentSlotsResponse
sourcepub fn new() -> GetAppointmentSlotsResponse
pub fn new() -> GetAppointmentSlotsResponse
The response of fetching appointment slots based on service context.